@@ -44,7 +44,7 @@ impl Component for Link {
     fn view(&self) -> Html {
         let mut classes = Classes::new();
         if let Some(style) = self.props.style.clone() {
-            classes.push(format!("link-{}", style.to_bootstrap()));
+            classes.push(format!("link-{}", style));
         }
         if self.props.stretched {
             classes.push("stretched-link");
